Skip to contents

Plots treated and synthetic control trajectories and overlays a 2x2 diff-in-diff diagram of our estimator. Requires ggplot2

Usage

ssynthdid_plot(estimate)

Arguments

estimate

A Ssynthdid model

Value

A list with all the plots for the different treatment periods.