Skip to contents

Plots unit by unit difference-in-differences. Dot size indicates the weights omega_i used in the average that yields our treatment effect estimate.

Usage

ssynthdid_units_plot(estimate)

Arguments

estimate

A Ssynthdid model

Value

A list with all the plots for the different treatment periods.